@@ -24,6 +24,21 @@ class TorchClientInterFace:
     @abstractmethod
     def delete_job(self, job: Job = None): raise NotImplementedError
 
+    @abstractmethod
+    def create_datasource(self, datasource: DataSource): raise NotImplementedError
+
+    @abstractmethod
+    def create_asset(self, asset: CreateAsset): raise NotImplementedError
+
+    @abstractmethod
+    def initialise_snapshot(self, snapshot_data): raise NotImplementedError
+
+    @abstractmethod
+    def get_current_snapshot(self, assembly_id: int): raise NotImplementedError
+
+    @abstractmethod
+    def create_asset_relation(self, asset_relation): raise NotImplementedError
+
     @abstractmethod
     def create_pipeline_run(self, pipeline_run): raise NotImplementedError
 
