@@ -5,7 +5,6 @@ from typing import List
 from acceldata_sdk.models.job import CreateJob
 from acceldata_sdk.models.span import Span
 from acceldata_sdk.models.span_context import SpanContext
-from datetime import datetime
 
 
 @dataclass
@@ -130,7 +129,7 @@ class PipelineRun:
     def __init__(self, pipelineId, versionId=None, status=PipelineRunStatus.STARTED, id=None, startedAt=None,
                  finishedAt=None, result=PipelineRunResult.UNKNOWN, client=None, args=None,
                  continuationId=None, successEvents=None, errorEvents=None, warningEvents=None, avgExecutionTime=None,
-                 *argumentss, **kwargs):
+                 **kwrgs):
         """
         Description:
                 Pipeline run used for instantiate run of the pipeline. To create new pipeline run you need to pass pipelineId, version.
@@ -170,66 +169,6 @@ class PipelineRun:
     def __repr__(self):
         return f"PipelineRun({self.__dict__})"
 
-    # convert job object to dict type
-    def _convert_job_to_dict(self, job: CreateJob):
-        """
-        Description:
-            Convert createJob class instance to dict type
-        :param job: createJob class instance
-        :return: dict form of createJob class instance
-        """
-        job_dict = job.__dict__
-        if hasattr(job, 'meta'):
-            meta = asdict(job.meta)
-            job_dict['meta'] = meta
-        input_dict = []
-        for ds_in in job.inputs:
-            input_dict.append(asdict(ds_in, dict_factory=lambda x: {k: v for (k, v) in x if v is not None}))
-        output_dict = []
-        for ds_out in job.outputs:
-            output_dict.append(asdict(ds_out, dict_factory=lambda x: {k: v for (k, v) in x if v is not None}))
-        job_dict['inputs'] = input_dict
-        job_dict['outputs'] = output_dict
-        job_dict['version'] = self.versionId
-        return job_dict
-
-    # create job for pipeline run
-    def create_job(self, job: CreateJob):
-        """
-        Description:
-            used to create job for any pipeline run
-        :return: Job class instance of created job        """
-        if job.uid is None or job.name is None:
-            raise Exception('To create a job job uid and name are required')
-        payload = self._convert_job_to_dict(job)
-        res = self.client.create_job(payload, self.pipelineId)
-        if job.bounded_by_span and job.span_uid is not None:
-            associated_job_uids = [job.uid]
-            span_uid_temp = job.span_uid
-            # Get root span to create child span under
-            parent_span_context = self.get_root_span()
-            if parent_span_context is not None:
-                # Create child span under root span
-                span_context = parent_span_context.create_child_span(
-                    uid=span_uid_temp,
-                    context_data={
-                        'time': str(datetime.now())
-                    },
-                    associatedJobUids=associated_job_uids
-                )
-            else:
-                # Create root span under pipeline_run as root span doesn't exist
-                self.create_span(
-                    uid=span_uid_temp,
-                    context_data={
-                        'time': str(datetime.now())
-                    },
-                    associatedJobUids=associated_job_uids
-                )
-        else:
-            raise Exception('To create a span span_uid is required')
-        return res
-
     # convert pipeline run to dict type
     def _convert_pipeline_run_to_dict(self, pipeline_run=None):
         """
@@ -283,8 +222,8 @@ class PipelineRun:
         Description:
             used to create span for any pipeline run
         :param associatedJobUids: list of string (job uids)
-        :param context_data
-        :param uid: span uid
+        :param context_data:
+        :param spanUid: span uid
         :return: SpanContext of the span
         """
         if uid is None:
@@ -295,9 +234,6 @@ class PipelineRun:
         )
         if associatedJobUids is None:
             associatedJobUids = []
-        elif not isinstance(associatedJobUids, list):
-            raise Exception('associatedJobUids should be a list')
-
         payload = self._convert_span_to_dict(create_span, associatedJobUids)
         res = self.client.create_span(self.id, payload)
         span_context = SpanContext(client=self.client, span=res, context_data= context_data, new_span = True)
@@ -310,7 +246,7 @@ class PipelineRun:
         :param span_uid: uid of the span
         :return: SpanContext instance of the input span uid
         """
-        span = self.client.get_span(pipeline_run_id= self.id, uid=span_uid)
+        span = self.client.get_span( pipeline_run_id= self.id,uid= span_uid)
         span_context = SpanContext(client=self.client, span= span)
         return span_context
 
@@ -320,10 +256,8 @@ class PipelineRun:
                 Get root span of the pipeline run
         :return: SpanContext instance of the root span
         """
-        span_context = None
         span = self.client.get_root_span( pipeline_run_id=self.id)
-        if span is not None:
-            span_context = SpanContext(client=self.client, span=span)
+        span_context = SpanContext(client=self.client, span=span)
         return span_context
 
     def get_details(self):
@@ -377,7 +311,7 @@ class Node:
                  uid = None,
                  createdVia: NodeAddition = NodeAddition.PIPELINE_CREATION,
                  status: NodeStatus = NodeStatus.ACTIVE,
-                 parentId = None, *args, **kwargs
+                 parentId = None
                  ):
         self.id = id
         self.type = type
@@ -415,7 +349,7 @@ class Edge:
                  toId = None,
                  fromAssetType: NodeType = None,
                  toAssetType: NodeType = None,
-                 versionId = None, *args, **kwargs
+                 versionId = None
                  ):
         self.id = id
         self.fromId = fromId
@@ -445,7 +379,7 @@ class Pipeline:
                  context=None,
                  client=None,
                  tags=None,
-                 *args, **kwargs):
+                 **kwrgs):
         """
         Description:
             Class of the pipeline
@@ -502,9 +436,8 @@ class Pipeline:
         :return: dict form of createJob class instance
         """
         job_dict = job.__dict__
-        if hasattr(job, 'meta'):
-            meta = asdict(job.meta)
-            job_dict['meta'] = meta
+        meta = asdict(job.meta)
+        job_dict['meta'] = meta
         input_dict = []
         for ds_in in job.inputs:
             input_dict.append(asdict(ds_in, dict_factory=lambda x: {k: v for (k, v) in x if v is not None}))
@@ -513,49 +446,22 @@ class Pipeline:
             output_dict.append(asdict(ds_out, dict_factory=lambda x: {k: v for (k, v) in x if v is not None}))
         job_dict['inputs'] = input_dict
         job_dict['outputs'] = output_dict
-        pipeline_run = self.client.get_pipeline_run(job.pipeline_run_id)
-        job_dict['version'] = pipeline_run.versionId
+        job_dict['pipelineUid'] = self.uid
         return job_dict
 
     # to create job for any given pipeline
     def create_job(self, job: CreateJob):
         """
         Description:
-            Used to create job and span in a pipeline
+            Used to create job in a pipeline
         :param job: createJob class instance that you want to add in pipeline
         :return: Job class instance of created job
         """
-        if job.uid is None or job.name is None or job.pipeline_run_id is None:
-            raise Exception('To create a job job uid, name and pipeline_run_id is required')
+        if job.uid is None or job.name is None:
+            raise Exception('To create a job, job uid, name is required')
 
         payload = self._convert_job_to_dict(job)
         res = self.client.create_job(payload, self.id)
-        if job.bounded_by_span and job.pipeline_run_id is not None and job.span_uid is not None:
-            associated_job_uids = [job.uid]
-            span_uid_temp = job.span_uid
-            # Get root span to create child span under
-            pipeline_run = self.get_run(job.pipeline_run_id)
-            parent_span_context = pipeline_run.get_root_span()
-            if parent_span_context is not None:
-                # Create child span under root span
-                span_context = parent_span_context.create_child_span(
-                    uid=span_uid_temp,
-                    context_data={
-                        'time': str(datetime.now())
-                    },
-                    associatedJobUids=associated_job_uids
-                )
-            else:
-                # Create root span under pipeline_run as root span doesn't exist
-                pipeline_run.create_span(
-                    uid=span_uid_temp,
-                    context_data={
-                        'time': str(datetime.now())
-                    },
-                    associatedJobUids=associated_job_uids
-                )
-        else:
-            raise Exception('To create a span span_uid and pipeline_run_id are required')
         return res
 
     # to delete pipeline
@@ -603,12 +509,8 @@ class Pipeline:
     def get_latest_pipeline_run(self) -> PipelineRun:
         return self.client.get_latest_pipeline_run(pipeline_id=self.id)
 
-    def get_run(self, pipeline_run_id=None, continuation_id=None) -> PipelineRun:
-        return self.client.get_pipeline_run(
-            pipeline_run_id=pipeline_run_id,
-            continuation_id=continuation_id,
-            pipeline_id=self.id
-        )
+    def get_run(self, pipeline_run_id) -> PipelineRun:
+        return self.client.get_pipeline_run(pipeline_run_id=pipeline_run_id)
 
     def get_runs(self) -> List[PipelineRun]:
         return self.client.get_pipeline_runs(pipeline_id=self.id)
@@ -618,7 +520,7 @@ class PipelineInfo:
     pipeline: Pipeline = None
     runs: List[PipelineRun] = list()
 
-    def __init__(self, pipeline=None, runs=None, *args, **kwargs):
+    def __init__(self, pipeline=None, runs=None):
         if isinstance(pipeline, dict):
             self.pipeline = Pipeline(**pipeline)
         else:
@@ -641,7 +543,7 @@ class PipelineDetails:
     nodes: List[Node] = list()
     edges: List[Edge] = list()
 
-    def __init__(self, pipeline=None, nodes=None, edges=None, *args, **kwargs):
+    def __init__(self, pipeline=None, nodes=None, edges=None):
         if isinstance(pipeline, dict):
             self.pipeline = Pipeline(**pipeline)
         else:
