@@ -6,36 +6,37 @@ from typing import List
 import requests
 
 from acceldata_sdk.models.connection import ConnectionType, AnalyticsPipeline, Connection, ConnectionCheck, ConnectionCheckStatus
-from acceldata_sdk.models.profile import Profile, ProfileRequest
+from acceldata_sdk.models.notifications import Notification, Incident
+from acceldata_sdk.models.profile import AutoProfileConfiguration, Profile, ProfileRequest
 from acceldata_sdk.models.rule import Rule, RuleCancelResponse, RuleExecution, ExecutionResult
-from acceldata_sdk.models.tags import TAG, AssetTag, AssetLabel
+from acceldata_sdk.models.setting import SettingGroup, Setting
+from acceldata_sdk.models.tags import TAG, Watch, AssetTag, AssetActivity, AssetComment, AssetLabel, User, APIKeys, \
+    ClassificationConfig
 from acceldata_sdk.errors import APIError, TorchSdkException
 from acceldata_sdk.models.assetType import AssetType
-from acceldata_sdk.models.datasource import DataSource,SourceType, CrawlerStatus
+from acceldata_sdk.models.datasource import CreateDataSource, DataSource,SourceType, CrawlerStatus, RootAsset
 from acceldata_sdk.models.job import Job
 from acceldata_sdk.models.pipeline import CreatePipeline, Pipeline, PipelineRun, PipelineInfo, PipelineDetails
+from acceldata_sdk.models.snapshot import SnapshotData
 from acceldata_sdk.models.span import Span, SpanContextEvent, CreateSpanEvent
 from acceldata_sdk.client import TorchClientInterFace
-from acceldata_sdk.models.asset import Asset, Metadata
+from acceldata_sdk.models.asset import Asset, AssetRelation, ChildAsset, Metadata
 from requests_toolbelt import MultipartEncoder
 from acceldata_sdk.models.dqrule import DataQualityExecutionResult, DataQualityRule, DataQualityRuleResource
 from acceldata_sdk.models.reconcillationrule import ReconcillationExecutionResult, ReconciliationRuleResource
 from acceldata_sdk.models.ruleExecutionResult import RuleResult, PolicyFilter, ExecutionPeriod, RuleType, RuleExecutionSummary
-from acceldata_sdk.constants import AssetSourceType, SdkSupportedVersions, TorchBuildVersion
+from acceldata_sdk.constants import AssetSourceType, SdkSupportedVersions
 from acceldata_sdk.common import Executor
-from acceldata_sdk.constants import PolicyType, FailureStrategy, RuleExecutionStatus, PipelineBulkupdateRequest
-from semantic_version import Version, SimpleSpec
-
+from acceldata_sdk.constants import PolicyType, FailureStrategy, RuleExecutionStatus
 
 from typing import List
-from dataclasses import asdict, dataclass
+from dataclasses import asdict
 import json
 from datetime import datetime, timedelta
 
 _HEADERS = {'User-Agent': 'Acceldata-sdk', 'accessKey': None, 'secretKey': None, 'Content-Type': 'application/json'}
 catalog_api_path = "/catalog-server/api"
 pipeline_api_path = "/torch-pipeline/api"
-admin_api_path = "/admin/api"
 
 import urllib3
 
@@ -73,12 +74,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self._timeout = 10000
         self._catalog_api_base = f"{url}{catalog_api_path}"
         self._pipeline_api_base = f"{url}{pipeline_api_path}"
-        loc = url.rfind('/torch')
-        if loc > 0:
-            self._admin_api_base = f"{url[:loc]}{admin_api_path}"
-        else:
-            self._admin_api_base = f"{url}{admin_api_path}"
-
         if access_key is None and secret_key is None:
             raise Exception('Access key and secret key - required')
         self.access_key = access_key
@@ -101,16 +96,14 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         return pipeline_dict
 
     def get_supported_sdk_versions(self) -> SdkSupportedVersions:
-        response = self._get(
-            f'{self._catalog_api_base}/sdk/compatible-versions'
-        )
-        return SdkSupportedVersions(**response['versions'])
 
-    def get_torch_version(self) -> TorchBuildVersion:
         response = self._get(
-            f'{self._admin_api_base}/build-details'
+
+            f'{self._catalog_api_base}/sdk/compatible-versions'
+
         )
-        return TorchBuildVersion(**response)
+
+        return SdkSupportedVersions(**response['versions'])
 
     # function to create pipeline
     def create_pipeline(self, pipeline: CreatePipeline) -> Pipeline:
@@ -130,23 +123,6 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self.logger.info('Pipeline Created')
         return Pipeline(**response['pipeline'])
 
-
-    def bulkupdate_pipeline(self, bulkUpdateRequest: PipelineBulkupdateRequest):
-        """
-        Description:
-            Used to bulk update pipeline
-        :param pipeline: createPipeline class instance that you want to create
-        :return: pipeline class instance
-        """
-        payload = asdict(bulkUpdateRequest)
-        response = self._post(
-            f'{self._pipeline_api_base}/pipelines/bulkupdate',
-            payload=payload, as_json=False
-        )
-        # response['pipeline']['client'] = self
-        self.logger.info(f'Pipelines Created')
-        return response
-
     # function to delete pipeline
     def delete_pipeline(self, id):
         """
@@ -207,6 +183,60 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self.logger.info('Pipeline Job Created')
         return Job(**response['node'])
 
+    # convert datasource to dict data type
+    def _convert_datasource_to_dict(self, datasource: CreateDataSource):
+        """
+            Description:
+                Convert CreateDataSource class instance to dict type
+            :param datasource: CreateDataSource class instance
+            :return: dict form of CreateDataSource class instance
+        """
+        payload = datasource.__dict__
+        source_type = asdict(datasource.sourceType)
+        payload['sourceType'] = source_type
+        datasource_payload = {}
+        if not datasource.isVirtual:
+            config_prop = []
+            for cp in datasource.configProperties:
+                config_prop.append(asdict(cp))
+            payload['properties'] = config_prop
+        payload.pop('configProperties')
+        datasource_payload['assembly'] = payload
+
+        return datasource_payload
+
+    # create datasource in torch
+    def create_datasource(self, datasource: CreateDataSource) -> DataSource:
+        """
+        Description:
+            used to create datasource
+        :param datasource: createDatasource class instance that you want to create
+        :return: created datasource instance
+        """
+        payload = self._convert_datasource_to_dict(datasource)
+        response = self._post(
+            f'{self._catalog_api_base}/assemblies',
+            payload=payload
+        )
+        response['data']['client'] = self
+        return DataSource(**response['data'])
+
+    def update_datasource(self, datasource_id: int, datasource: CreateDataSource) -> DataSource:
+        """
+        Description:
+            used to update datasource
+        :param datasource_id: id of the datasource to be updated
+        :param datasource: createDatasource class instance that you want to create
+        :return: created datasource instance
+        """
+        payload = self._convert_datasource_to_dict(datasource)
+        response = self._put(
+            f'{self._catalog_api_base}/assemblies/{datasource_id}',
+            payload=payload
+        )
+        response['data']['client'] = self
+        return DataSource(**response['data'])
+
     def delete_datasource(self, datasource_id: int):
         """
         Description:
@@ -219,6 +249,31 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return response
 
+    def get_root_asset(self, datasource_id):
+        response = self._get(
+            f'{self._catalog_api_base}/assemblies/{datasource_id}/rootAssets'
+        )
+        root_assets = list(response)
+        root_assets_list = []
+        for res in root_assets:
+            root_assets_list.append(RootAsset(**res))
+        return root_assets_list
+
+    # to create asset for any given datasource
+    def create_asset(self, asset: {}) -> Asset:
+        """
+        Description:
+            Used to create asset in a datasource
+        :param asset: (dict) asset input
+        :return: Asset class instance of created asset
+        """
+        response = self._put(
+            f'{self._catalog_api_base}/assets',
+            payload=asset
+        )
+        response['data']['client'] = self
+        return Asset(**response['data'])
+
     def start_crawler(self, datasource_name) -> CrawlerStatus:
         response = self._post(
             f'{self._catalog_api_base}/crawler/{datasource_name}',
@@ -226,12 +281,86 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return CrawlerStatus(**response['data'])
 
+    def restart_crawler(self, datasource_name) -> CrawlerStatus:
+        response = self._post(
+            f'{self._catalog_api_base}/crawler/{datasource_name}/restart',
+            payload={}
+        )
+        return CrawlerStatus(**response['data'])
+
+    def remove_crawler(self, datasource_name) -> CrawlerStatus:
+        response = self._delete(
+            f'{self._catalog_api_base}/crawler/{datasource_name}/restart'
+        )
+        return CrawlerStatus(**response['data'])
+
     def get_crawler_status(self, datasource_name) -> CrawlerStatus:
         response = self._get(
             f'{self._catalog_api_base}/crawler/{datasource_name}',
         )
         return CrawlerStatus(**response['data'])
 
+    # initialise new version of snapshot for a datasource
+    def initialise_snapshot(self, snapshot_data: {}) -> SnapshotData:
+        """
+        Description:
+            Used to initialise new version of snapshot for a datasource
+        :param snapshotData: dict of snapshotData class instance
+        :return: created snapshotData class instance
+        """
+        response = self._post(
+            f'{self._catalog_api_base}/snapshots/initialise',
+            payload=snapshot_data
+        )
+        return SnapshotData(**response['data'])
+
+    # get current version of datasource
+    def get_current_snapshot(self, datasource_id: int) -> SnapshotData:
+        """
+        Description:
+            If you want to get current version of a datasource
+        :param datasourceId: id of a datasource
+        :return: SnapshotData class instance of datasource
+        """
+        response = self._get(
+            f'{self._catalog_api_base}/snapshots/{datasource_id}/version'
+        )
+        return SnapshotData(**response)
+
+    def list_datasource_snapshots(self, id: int):
+        response = self._get(
+            f'{self._catalog_api_base}/snapshots/{id}'
+        )
+        snapshots = list(response)
+        snapshots_list = []
+        for res in snapshots:
+            snapshots_list.append(SnapshotData(**res))
+        return snapshots_list
+
+    def list_all_snapshots(self):
+        response = self._get(
+            f'{self._catalog_api_base}/snapshots'
+        )
+        snapshots = list(response)
+        snapshots_list = []
+        for res in snapshots:
+            snapshots_list.append(SnapshotData(**res))
+        return snapshots_list
+
+    # create relation between asset
+    def create_asset_relation(self, asset_relation: {}) -> AssetRelation:
+        """
+        Description:
+            used to create relation between any 2 existing assets
+        :param asset_relation: relation dict object
+        :return: created AssetRelation class instance
+        """
+        response = self._put(
+            f'{self._catalog_api_base}/asset-relations',
+            payload=asset_relation
+        )
+        return AssetRelation(**response['data'])
+
     # create run for a pipeline
     def create_pipeline_run(self, pipeline_run: {}) -> PipelineRun:
         """
@@ -280,47 +409,17 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         return PipelineRun(**response['run'])
 
     # get pipeline run with particular continuation id or run id
-    def get_pipeline_run(self, pipeline_run_id: int = None, continuation_id: str = None, pipeline_id: str = None) -> PipelineRun:
+    def get_pipeline_run(self, pipeline_run_id: int) -> PipelineRun:
         """
             Description:
-                To get pipeline run with particular id or continuation id of any pipeline
-        :param pipeline_run_id: run id of the pipeline run
-        :param continuation_id: continuation id of the pipeline run
-        :param pipeline_id: id of the pipeline. This is a mandatory parameter when run is being queried using continuation_id
+                To get pipeline run with particular id of any pipeline
+        :param pipeline_run_id: continuation id or run id of the pipeline run
         :return: PipelineRun instance
         """
-        payload = dict()
-        return_run = dict()
-        if pipeline_run_id is not None:
-            url = f'{self._pipeline_api_base}/pipelines/runs/{pipeline_run_id}'
-            response = self._get(url)
-            return_run = response['run']
-        elif continuation_id is not None and pipeline_id is not None:
-            supported_versions = self.get_supported_sdk_versions()
-            torch_version: str = self.get_torch_version()
-            if torch_version.buildVersion is not None and torch_version.buildVersion != "":
-                actual_version = torch_version.buildVersion[:5]
-            else:
-                actual_version = supported_versions.maxVersion
-            ver_comparator = SimpleSpec(f'<={actual_version}')
-            if Version('2.5.0') in ver_comparator:
-                url = f'{self._pipeline_api_base}/pipelines/{pipeline_id}/runs'
-                payload = {"continuationId": continuation_id}
-                response = self._get(url, params=payload)
-                return_run = response["runs"][0]
-            else:
-                # For torch versions lower than 2.5.0 use old call for continuation_id
-                if continuation_id.isdigit() is False:
-                    url = f'{self._pipeline_api_base}/pipelines/runs/{continuation_id}'
-                    response = self._get(url)
-                    return_run = response['run']
-                else:
-                    raise TorchSdkException('Please provide continuation_id which is not a valid number.')
-        else:
-            raise TorchSdkException('Please provide either continuation_id and pipeline_id or pipeline_run_id')
-
-        return_run['client'] = self
-        return PipelineRun(**return_run)
+        url = f'{self._pipeline_api_base}/pipelines/runs/{pipeline_run_id}'
+        response = self._get(url)
+        response['run']['client'] = self
+        return PipelineRun(**response['run'])
 
     # get pipeline runs for a pipeline
     def get_pipeline_runs(self, pipeline_id: int) -> List[PipelineRun]:
@@ -345,7 +444,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         Description:
             used to create span for any pipeline run
         :param pipeline_run_id:
-        :param span: Span class instance
+        :param span: Span class instace
         :return: Span
         """
         response = self._post(
@@ -391,14 +490,9 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         response = self._get(url, params=params)
         print(f'response: {response}')
         return_value = dict()
-        return_value['span'] = dict()
+        return_value['span'] = response['spans'][0]
         return_value['span']['client'] = self
-        if response['spans']:
-            return_value['span'] = response['spans'][0]
-            return_value['span']['client'] = self
-            return Span(**return_value['span'])
-        else:
-            return None
+        return Span(**return_value['span'])
 
     def get_spans(self, pipeline_run_id):
         response = self._get(
@@ -511,6 +605,54 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             tags_list.append(TAG(**res))
         return tags_list
 
+    def delete_tag(self, tag):
+        tags = self.get_tags()
+        tag_id = None
+        for tg in tags:
+            if tg.name == tag:
+                tag_id = tg.id
+        if tag_id is None:
+            raise TorchSdkException(f'Tag not found with name {tag}')
+        response = self._delete(
+            url=f'{self._catalog_api_base}/tag/{tag_id}'
+        )
+        return response
+
+    def update_data_protection(self, tag: str, is_protected: bool):
+        payload = {
+            'isProtected': is_protected
+        }
+        tags = self.get_tags()
+        tag_id = None
+        for tg in tags:
+            if tg.name == tag:
+                tag_id = tg.id
+        if tag_id is None:
+            raise TorchSdkException(f'Tag not found with name {tag}')
+        response = self._put(
+            url=f'{self._catalog_api_base}/tags/{tag_id}',
+            payload=payload
+        )
+        return response
+
+    def discover(self):
+        url = f'{self._catalog_api_base}/assets/discover?page=0&size=25'
+        response = self._get(url)
+        datasource = list(response['data']['assemblies'])
+        ds_list = []
+        for res in datasource:
+            ds_list.append(DataSource(**res))
+
+        assets = list(response['data']['assets'])
+        assets_list = []
+        for res in assets:
+            assets_list.append(Asset(**res))
+        response = {
+            'datasources': ds_list,
+            'assets': assets_list
+        }
+        return response
+
     def get_datasource(self, assembly_identifier, properties: bool = False) -> DataSource:
         """
         Description:
@@ -610,6 +752,12 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return response
 
+    def delete_asset(self, id: int):
+        response = self._delete(
+            url=f'{self._catalog_api_base}/assets/{id}'
+        )
+        return response
+
     def get_asset_metadata(self, id: int):
         url = f'{self._catalog_api_base}/assets/{id}/metadata'
         response = self._get(
@@ -618,6 +766,15 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         metadata = Metadata(**response['data'])
         return metadata
 
+    def update_asset_metadata(self, id: int, metadata: dict):
+        url = f'{self._catalog_api_base}/assets/{id}/metadata'
+        response = self._put(
+            url=url,
+            payload=metadata
+        )
+        metadata = Metadata(**response['data'])
+        return metadata
+
     def add_custom_metadata(self, id: int, custom_metadata: dict):
         url = f'{self._catalog_api_base}/assets/{id}/metadata/custom'
         response = self._post(
@@ -637,6 +794,16 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         profile_response = Profile(**response['data'])
         return profile_response
 
+    def auto_tag_asset(self, id: int, payload: dict):
+        url = f'{self._catalog_api_base}/assets/{id}/autotag'
+        response = self._post(
+            url=url,
+            payload=payload
+        )
+        response['data']['client'] = self
+        profile_response = Profile(**response['data'])
+        return profile_response
+
     def sample_data(self, id: int):
         url = f'{self._catalog_api_base}/assets/{id}/sample'
         response = self._get(
@@ -668,6 +835,51 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return response['result']
 
+    def get_related_assets(self, id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/relatedAssets'
+        response = self._get(
+            url=url
+        )
+        relations = list(response['relations'])
+        relations_list = []
+        for res in relations:
+            relations_list.append(AssetRelation(**res))
+        return relations_list
+
+    def get_child_assets(self, id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/childAssets'
+        response = self._get(
+            url=url
+        )
+        child_assets = list(response['childAssets'])
+        child_assets_list = []
+        for res in child_assets:
+            child_assets_list.append(ChildAsset(**res))
+        return child_assets_list
+
+    def start_watch(self, id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/watch'
+        response = self._post(
+            url=url
+        )
+        start_watch = Watch(**response['data'])
+        return start_watch
+
+    def stop_watch(self, id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/watch'
+        response = self._delete(
+            url=url
+        )
+        return response
+
     def get_asset_tags(self, id: int):
         if id is None:
             raise Exception('Asset id is required')
@@ -690,6 +902,15 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return AssetTag(**response)
 
+    def remove_asset_tag(self, id: int, tag_id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/removeTag/{tag_id}'
+        response = self._delete(
+            url=url
+        )
+        return response
+
     def add_asset_labels(self, id: int, payload: dict):
         if id is None:
             raise Exception('Asset id is required')
@@ -716,12 +937,204 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             labels_list.append(AssetLabel(**lbl))
         return labels_list
 
+    def list_all_classification_configurations(self):
+        url = f'{self._catalog_api_base}/classification-configs?sortBy=name:ASC&page=0&size=50'
+        response = self._get(
+            url=url
+        )
+        configs = list(response['classificationConfigs'])
+        configs_list = []
+        for res in configs:
+            configs_list.append(ClassificationConfig(**res))
+        return configs_list
+
+    def get_classification_configuration(self, name: str):
+        url = f'{self._catalog_api_base}/classification-configs?sortBy=name:ASC&page=0&size=50'
+        response = self._get(
+            url=url
+        )
+        configs = list(response['classificationConfigs'])
+        config_requested = None
+        for res in configs:
+            config = ClassificationConfig(**res)
+            if config.name == name:
+                config_requested = config
+        if config_requested is None:
+            raise TorchSdkException(f'Classification not found with {name}.')
+        return config_requested
+
+    def delete_classification_configuration(self, name: str):
+        config = self.get_classification_configuration(name)
+        if config is not None:
+            response = self._delete(
+                url=f'{self._catalog_api_base}/classification-configs/{config.id}'
+            )
+            return response
+        else:
+            raise TorchSdkException(f'Error deleting config. Classification config not found with {name}.')
+
+    def create_classification_configuration(self, classification_config):
+        url = f'{self._catalog_api_base}/classification-configs'
+        payload = {
+            'classificationConfig': classification_config.__dict__
+        }
+        response = self._post(
+            url=url,
+            payload=payload
+        )
+        return ClassificationConfig(**response)
+
+    def update_classification_configuration(self, classification_config):
+        if classification_config.id is None:
+            raise TorchSdkException(f'Classification id is required to update it.  {classification_config.name}')
+        url = f'{self._catalog_api_base}/classification-configs'
+        payload = {
+            'classificationConfig': classification_config.__dict__
+        }
+        response = self._put(
+            url=url,
+            payload=payload
+        )
+        return ClassificationConfig(**response)
+
+    def list_setting_groups(self):
+        url = f'{self._catalog_api_base}/settinggroups'
+        response = self._get(
+            url=url
+        )
+        settings = list(response)
+        settings_list = []
+        for res in settings:
+            settings_list.append(SettingGroup(**res))
+        return settings_list
+
+    def find_settings_by_group(self, setting_group_name):
+        group_id = None
+        setting_group_list = self.list_setting_groups()
+        for setting in setting_group_list:
+            if setting.name == setting_group_name:
+                group_id = setting.id
+        if group_id is None:
+            raise TorchSdkException(f'Setting group not found with name {setting_group_name}')
+
+        url = f'{self._catalog_api_base}/settinggroups/{group_id}'
+        response = self._get(
+            url=url
+        )
+        settings = list(response['settings'])
+        settings_list = []
+        for res in settings:
+            settings_list.append(Setting(**res['setting']))
+        return settings_list
+
+    def get_setting(self, key: str):
+        if key is None:
+            raise Exception('Setting key is required.')
+        url = f'{self._catalog_api_base}/setting/{key}'
+        response = self._get(
+            url=url
+        )
+        return Setting(**response)
+
+    def update_setting_value(self, key: str, value: str):
+        setting = self.get_setting(key)
+        if setting is None:
+            raise TorchSdkException(f'Setting not found with name {key}')
+        payload = {
+            "settingValue": str(value)
+        }
+        url = f'{self._catalog_api_base}/setting/{setting.id}'
+        response = self._put(
+            url=url, payload=payload
+        )
+        return response
+
+    def reset_setting_value(self, key: str):
+        setting = self.get_setting(key)
+        if setting is None:
+            raise TorchSdkException(f'Setting not found with name {key}')
+        payload = {}
+        url = f'{self._catalog_api_base}/setting/{setting.id}?operation=reset'
+        response = self._put(
+            url=url, payload=payload
+        )
+        return response
+
+    def update_asset_annotation(self, id: int, payload: dict):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/annotation'
+        response = self._put(
+            url=url, payload=payload
+        )
+        return response
+
+    def get_asset_activity(self, id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/activity'
+        response = self._get(
+            url=url
+        )
+        return AssetActivity(**response)
+
+    def get_asset_comment(self, id: int):
+        if id is None:
+            raise Exception('Asset id is required')
+        url = f'{self._catalog_api_base}/assets/{id}/comments'
+        response = self._get(
+            url=url
+        )
+        comments = list(response['comments'])
+        comments_list = []
+        for res in comments:
+            comments_list.append(AssetComment(**res))
+        return comments_list
+
+    def get_user_by_id(self, id: int) -> User:
+        if id is None:
+            raise TorchSdkException('User id is required')
+        url = f'{self._catalog_api_base}/user/{id}'
+        response = self._get(
+            url=url
+        )
+        return User(**response)
+
+    def get_user_by_name(self, username: int) -> User:
+        if id is None:
+            raise TorchSdkException('Username is required')
+        url = f'{self._catalog_api_base}/user/byname/{username}'
+        response = self._get(
+            url=url
+        )
+        return User(**response)
+
+    def list_all_analysis_pipelines(self):
+        response = self._get(
+            url=f'{self._catalog_api_base}/analytics-pipelines'
+        )
+        keys = list(response['pipelines'])
+        keys_list = []
+        for res in keys:
+            keys_list.append(AnalyticsPipeline(**res))
+        return keys_list
+
     def get_analysis_pipeline(self, id: int) -> AnalyticsPipeline:
         response = self._get(
             url=f'{self._catalog_api_base}/analytics-pipelines/{id}'
         )
         return AnalyticsPipeline(**response['pipeline'])
 
+    def list_all_connections(self):
+        response = self._get(
+            url=f'{self._catalog_api_base}/connections'
+        )
+        connections = list(response['connections'])
+        conn_list = []
+        for res in connections:
+            conn_list.append(Connection(**res))
+        return conn_list
+
     def check_connection(self, create_connection):
         create_conn = create_connection.__dict__
         config_prop = []
@@ -743,6 +1156,13 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             raise TorchSdkException(f'Error: {check_res.message}')
         return check_res
 
+    def get_connection(self, name):
+        connections = self.list_all_connections()
+        for conn in connections:
+            if name == conn.name:
+                return conn
+        raise TorchSdkException(f'No connection found with name {name}')
+
     def create_connection(self, create_connection) -> Connection:
         create_conn = create_connection.__dict__
         config_prop = []
@@ -759,6 +1179,106 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return Connection(**response['connection'])
 
+    def update_connection(self, name, update_connection) -> Connection:
+        connections = self.list_all_connections()
+        conn_id = None
+        for conn in connections:
+            if name == conn.name:
+                conn_id = conn.id
+        if conn_id is None:
+            raise TorchSdkException(f'No connection found with name {name}')
+        conn = update_connection.__dict__
+        config_prop = []
+        for cp in update_connection.properties:
+            config_prop.append(asdict(cp))
+        conn['properties'] = config_prop
+        payload = {
+            'connection': conn
+        }
+        url = f'{self._catalog_api_base}/connections/{conn_id}'
+        response = self._put_form_data(
+            url=url,
+            payload=payload
+        )
+        return Connection(**response['connection'])
+
+    def delete_connection(self, id):
+        response = self._delete(
+            url=f'{self._catalog_api_base}/connections/{id}'
+        )
+        return response
+
+    def get_all_auto_profile_configurations(self):
+        response = self._get(
+            url=f'{self._catalog_api_base}/assemblies/auto-profile-configurations'
+        )
+        configs = list(response)
+        auto_profile_list = []
+        for res in configs:
+            auto_profile_list.append(AutoProfileConfiguration(**res))
+        return auto_profile_list
+
+    def get_auto_profile_configuration(self, datasource_id: int) -> AutoProfileConfiguration:
+        response = self._get(
+            url=f'{self._catalog_api_base}/assemblies/{datasource_id}/auto-profile-configuration'
+        )
+        return AutoProfileConfiguration(**response)
+
+    def remove_auto_profile_configuration(self, datasource_id: int):
+        response = self._delete(
+            url=f'{self._catalog_api_base}/assemblies/{datasource_id}/auto-profile-configuration'
+        )
+        return response
+
+    def create_api_keys(self) -> APIKeys:
+        response = self._post(
+            url=f'{self._catalog_api_base}/key'
+        )
+        return APIKeys(**response['data'])
+
+    def get_api_keys(self):
+        response = self._get(
+            url=f'{self._catalog_api_base}/key'
+        )
+        keys = list(response['apiKeys'])
+        keys_list = []
+        for res in keys:
+            keys_list.append(APIKeys(**res))
+        return keys_list
+
+    def delete_api_key(self, access_key: str):
+        list = self.get_api_keys()
+        access_key_id = None
+        for i in list:
+            if i.accessKey == access_key:
+                access_key_id = i.id
+        if access_key_id is None:
+            raise TorchSdkException(f'Access key {access_key} not found in torch catalog.')
+        response = self._delete(
+            url=f'{self._catalog_api_base}/key/{access_key_id}'
+        )
+        return response
+
+    def get_notifications(self):
+        response = self._get(
+            url=f'{self._catalog_api_base}/notifications?page=0&size=50&sortBy=id:DESC'
+        )
+        notifications = list(response['notification'])
+        notifications_list = []
+        for res in notifications:
+            notifications_list.append(Notification(**res))
+        return notifications_list
+
+    def get_incidents(self):
+        response = self._get(
+            url=f'{self._catalog_api_base}/incidents'
+        )
+        incidents = list(response['incidents'])
+        inc_list = []
+        for res in incidents:
+            inc_list.append(Incident(**res))
+        return inc_list
+
     def enable_rule(self, rule_id) -> Rule:
         payload = {
             "enable": True
@@ -787,7 +1307,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         return RuleCancelResponse(**response['result'])
 
     def execute_rule(self, rule_type: PolicyType, rule_id, sync=True, incremental=False,
-                     failure_strategy: FailureStrategy = FailureStrategy.DoNotFail, pipeline_run_id=None):
+                     failure_strategy: FailureStrategy = FailureStrategy.DoNotFail):
         """
         Description:
             To execute rule synchronously and asynchronously
@@ -799,7 +1319,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             fail at warning or never fail
         """
         rule_executor = Executor(rule_type, self, sync=sync)
-        rule_executor.execute(rule_id, incremental, failure_strategy=failure_strategy, pipeline_run_id=pipeline_run_id)
+        rule_executor.execute(rule_id, incremental, failure_strategy=failure_strategy)
         return rule_executor
 
     def get_rule_status(self, rule_type, execution_id) -> RuleExecutionStatus:
@@ -824,26 +1344,20 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         rule_executor = Executor(rule_type, self)
         return rule_executor.get_execution_result(execution_id, failure_strategy=failure_strategy)
 
-    def execute_dq_rule(self, rule_id, incremental=False, pipeline_run_id=None) -> RuleExecution:
-        payload_temp = dict()
-        payload_temp['executionType'] = "FULL"
+    def execute_dq_rule(self, rule_id, incremental=False) -> RuleExecution:
+        payload_temp = {"executionType": "FULL"}
         if incremental:
-            payload_temp['executionType'] = "INCREMENTAL"
-        if pipeline_run_id is not None:
-            payload_temp['pipelineRunId'] = pipeline_run_id
+            payload_temp = {"executionType": "INCREMENTAL"}
         response = self._post(
             url=f'{self._catalog_api_base}/rules/data-quality/{rule_id}/executions',
             payload=payload_temp
             )
         return RuleExecution(**response['execution'])
 
-    def execute_reconciliation_rule(self, rule_id, incremental=False, pipeline_run_id=None) -> RuleExecution:
-        payload_temp = dict()
-        payload_temp['executionType'] = "FULL"
+    def execute_reconciliation_rule(self, rule_id, incremental=False) -> RuleExecution:
+        payload_temp = {"executionType": "FULL"}
         if incremental:
-            payload_temp['executionType'] = "INCREMENTAL"
-        if pipeline_run_id is not None:
-            payload_temp['pipelineRunId'] = pipeline_run_id
+            payload_temp = {"executionType": "INCREMENTAL"}
         response = self._post(
             url=f'{self._catalog_api_base}/rules/reconciliation/{rule_id}/executions',
             payload=payload_temp
@@ -897,7 +1411,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         rule_id = identifier
         if not check_int(identifier):
             if rule_type.value == RuleType.DATA_QUALITY.value:
-                rule_res = self.get_dq_rule(identifier)
+                rule_res =  self.get_dq_rule(identifier)
             elif rule_type.value == RuleType.RECONCILIATION.value:
                 rule_res = self.get_reconciliation_rule(identifier)
             rule_id = rule_res.rule.id
