@@ -1,88 +1,101 @@
 from acceldata_sdk.torch_client import TorchClient
 import acceldata_sdk.constants as const
-
+from acceldata_sdk.models.tags import AssetLabel
 from acceldata_sdk.models.profile import ProfilingType
 from acceldata_sdk.models.profile import AutoProfileConfiguration, Profile, ProfileRequest, ProfilingType
 import pprint
 
 pp = pprint.PrettyPrinter(indent=4)
+
+# base_path = 's3a://demo-data-plane-one/execution_result'
+# good_data_location = 's3a://demo-data-plane-one/execution_result/2022-09-29/segmented_cc/_1664445283208/successrecords'
+# stage_path_suffix=good_data_location.lstrip(base_path)
+
+#
+# torch_client = TorchClient(url='https://dataplaneone.cp.torch.demo.acceldata.dev/torch', access_key='3557ZXXOEYVCCX0', secret_key='FH8YHP3GZPFHIAH5MWQOIZKSSK202C', do_version_check=False)
+#
+# recon_rule_id=132
+# # import pdb;pdb.set_trace()
+# sync_execution_result = torch_client.get_policy_execution_result(const.PolicyType.DATA_QUALITY, 30)
+# import json
+# persitence_paths = json.loads(sync_execution_result.execution.persistencePath)
+# persitence_path_configs = persitence_paths['persistencePathConfigs']
+# for path in persitence_path_configs:
+#     if path['recordType'] == 'GOOD':
+#         base_path = path['basePath']
+# good_data_location = sync_execution_result.execution.resultPersistencePath['goodDataLocation']
+# stage_path_suffix=good_data_location.lstrip(base_path)
+# stage_name='@shubh_ext_stage2/'
+# stage_load_data_path = stage_name + stage_path_suffix
+# pp(stage_load_data_path)
+
+
+# sync_execution_result = recon_rule2.get_result()
+
 # pipeline_uid = "torch.airflow.demo.lambda"
 # torch_credentials = {
 #     'url': 'https://torchdemo.acceldata.tech/torch',
 #     'access_key': 'V05DG18TV4MAF93',
 #     'secret_key': 'VZF8O9Q5G6GUE08MQY5A8CA0TAE5KD'
 # }
-# torch_credentials = {
-#     'url': 'https://torch.acceldata.local:5443/torch',
-#     'access_key': 'P04IM8FNQRUCRTU',
-#     'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5',
-#     'do_version_check': False
-# }
-
-
+torch_credentials = {
+    'url': 'https://torch.acceldata.local:5443/torch',
+    'access_key': 'P04IM8FNQRUCRTU',
+    'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5',
+    'do_version_check': 'True'
+}
 # torch_credentials = {
 #     'url': 'https://yubi.torch.acceldata.dev/torch',
 #     'access_key': 'SAQ8XAOLSSLAD16',
 #     'secret_key': 'KL5C4UA5XBQ2HBUMQPATJ3FB45HRH9'
 # }
 
+######## suman 2.3.0 test
+# torch_credentials = {
+#     'url': 'https://torchtenant.unified.acceldata.tech',
+#     'access_key': 'TXU3N9MDGN7ZIZD',
+#     'secret_key': 'OGWX9ONR37CQFKL2EL7S4NBKPY433G'
+# }
+# torch_credentials = {
+#     'url': 'https://jeevan.verisk.demo.acceldata.tech/torch',
+#     'access_key': 'HVN976UDHFQUJ52',
+#     'secret_key': '57RBZ3693XA3DC92UN3A4XS42JXV6X'
+# }
 
-
-torch_credentials = {
-    'url': 'https://torch.acceldata.local:5443/torch',
-    'access_key': 'P04IM8FNQRUCRTU',
-    'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5'
-}
-
-
-torch_client = TorchClient(**torch_credentials)
-# pipelines = torch_client.get_pipelines()
-# print (f"number of pipelines: {len(pipelines)}")
-# for pipeline in pipelines:
-#     print(f"pipeline id: {pipeline.pipeline.id}")
-#     if pipeline.pipeline.id > 77:
-#         print (f"pipeline id being deleted: {pipeline.pipeline.id}")
-#         pipeline.pipeline.delete()
-i = 77
-while i<150:
-    try:
-        pipeline = torch_client.get_pipeline(i)
-        if pipeline is not None:
-            print(f'deleting {i}')
-            pipeline.delete()
-    except:
-        print (f'{i} not found')
-    i = i+1
-
-
-
-
-exit()
-pipeline_uid = "torch.test"
-
-
-pipeline = torch_client.get_pipeline(pipeline_uid)
-pipeline_run = pipeline.create_pipeline_run()
-run_with_id = pipeline.get_run(pipeline_run.id)
-exit()
-
-# recon_rule_id=4
-# import pdb;pdb.set_trace()
-# recon_rule2 = torch_client.execute_rule(const.RECONCILIATION, recon_rule_id, sync=True, incremental=False, pipeline_run_id=401)
-# sync_execution_result = recon_rule2.get_result()
-# exit(0)
-
-
-#### pipelines ###
-
+#    TORCH_CATALOG_URL: "https://jeevan.verisk.demo.acceldata.tech/torch"
+#    TORCH_ACCESS_KEY: "HVN976UDHFQUJ52"
+#    TORCH_SECRET_KEY: "57RBZ3693XA3DC92UN3A4XS42JXV6X"
 torch_client = TorchClient(**torch_credentials)
 supported_versions = torch_client.get_supported_sdk_versions()
 pp.pprint('supported_versions')
 pp.pprint(supported_versions)
 
 
+# asset = torch_client.get_asset(95775)
+# jeevan verisk torch enterprise
+asset = torch_client.get_asset(4)
 
+pp.pprint('asset')
+pp.pprint(asset)
+metadata_asset = asset.get_metadata()
+pp.pprint('metadata_asset')
+pp.pprint(metadata_asset)
+# sample_asset = asset.sample_data()
+# pp.pprint('sample_asset')
+# pp.pprint(sample_asset)
 
+asset.add_labels(labels=[AssetLabel('test1', 'shubh1'), AssetLabel('test2', 'shubh3')])
+labels_asset = asset.get_labels()
+pp.pprint('labels_asset')
+pp.pprint(labels_asset)
+exit()
+###############
+
+#### pipelines ###
+torch_client = TorchClient(**torch_credentials)
+supported_versions = torch_client.get_supported_sdk_versions()
+pp.pprint('supported_versions')
+pp.pprint(supported_versions)
 
 pipeline = torch_client.get_pipeline(42)
 pp.pprint('pipeline')
